﻿using IRaCIS.Core.Domain.Share;
using IRaCIS.Core.Infrastructure;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Filters;
using Microsoft.Extensions.Localization;
using Microsoft.Extensions.Logging;

namespace IRaCIS.Core.Application.Filter;

public class ProjectExceptionFilter(ILogger<ProjectExceptionFilter> _logger, IStringLocalizer _localizer) : Attribute, IExceptionFilter
{

    public void OnException(ExceptionContext context)
    {
        //context.ExceptionHandled;//记录当前这个异常是否已经被处理过了

        var exception = context.Exception;

        if (!context.ExceptionHandled)
        {
            if (exception.GetType().Name == "DbUpdateConcurrencyException")
            {
                //---并发更新，当前不允许该操作
                context.Result = new JsonResult(ResponseOutput.NotOk(_localizer["ProjectException_ConcurrentUpdateNotAllowed"] + exception.Message));
            }

            if (exception.GetType() == typeof(BusinessValidationFailedException))
            {
                var error = exception as BusinessValidationFailedException;

                var info = string.Empty;

                if (!string.IsNullOrWhiteSpace(error!.LocalizedKey) && StaticData.Localizer_Dev_Dic.ContainsKey(error!.LocalizedKey))
                {
                    info = $"[{error!.LocalizedKey}]:{StaticData.Localizer_Dev_Dic[error!.LocalizedKey]}";
                }


                context.Result = new JsonResult(ResponseOutput.NotOk(exception.Message, "", error!.Code, localizedInfo: info));

            }
            else if (exception.GetType() == typeof(QueryBusinessObjectNotExistException))
            {
                context.Result = new JsonResult(ResponseOutput.NotOk(exception.Message, ApiResponseCodeEnum.DataNotExist));
            }
            else
            {
                context.Result = new JsonResult(ResponseOutput.NotOk(_localizer["Project_ExceptionContactDeveloper"] + (exception.InnerException is null ? (exception.Message)
                    : (exception.InnerException?.Message )), ApiResponseCodeEnum.ProgramException));

            }

            context.ExceptionHandled = true;//标记当前异常已经被处理过了


            var errorInfo = $"Exception: {exception.Message}[{exception.StackTrace}]" + (exception.InnerException != null ? $" InnerException: {exception.InnerException.Message}[{exception.InnerException.StackTrace}]" : "");

            _logger.LogError(errorInfo);

        }
        else
        {
            //继续
        }
    }
}
